@@ -12,7 +12,7 @@ ACTIONS:
  leave          remove the specified user from your following list
  public         get latest public tweets
  replies        get latest replies
- search         searchtwitter (Beware: octothorpe, escape it)
+ search         search twitter (Beware: octothorpe, escape it)
  set            set your twitter status
  shell          login the twitter shell
 
@@ -319,6 +319,7 @@ class SearchAction(Action):
         # We need to be pointing at search.twitter.com to work, and it is less
         # tangly to do it here than in the main()
         twitter.domain="search.twitter.com"
+        twitter.uri=""
         # We need to bypass the TwitterCall parameter encoding, so we
         # don't encode the plus sign, so we have to encode it ourselves
         query_string = "+".join([quote(term) for term in options['extra_args']])
@@ -457,6 +458,9 @@ paste or type it here:
     webbrowser.open(
         'http://api.twitter.com/oauth/authorize?oauth_token=' +
         oauth_token)
+    time.sleep(2) # Sometimes the last command can print some
+                  # crap. Wait a bit so it doesn't mess up the next
+                  # prompt.
     oauth_verifier = raw_input("Please type the PIN: ").strip()
     twitter = Twitter(
         auth=OAuth(
@@ -468,6 +472,7 @@ paste or type it here:
     print >> oauth_file, oauth_token
     print >> oauth_file, oauth_token_secret
     oauth_file.close()
+    print
     print "That's it! Your authorization keys have been written to %s." % (
         options['oauth_filename'])
 
@@ -534,7 +539,8 @@ def main(args=sys.argv[1:]):
     twitter = Twitter(
         auth=OAuth(
             oauth_token, oauth_token_secret, CONSUMER_KEY, CONSUMER_SECRET),
-        secure=options['secure'])
+        secure=options['secure'],
+        api_version='1')
 
     try:
         Action()(twitter, options)
